@@ -1,8 +1,11 @@
 import test from 'ava';
-import camelCase from '.';
+import camelCase from './index.js';
 
 test('camelCase', t => {
 	t.is(camelCase('foo'), 'foo');
+	/// https://github.com/sindresorhus/camelcase/issues/95
+	/// t.is(camelCase('IDs'), 'ids');
+	/// t.is(camelCase('FooIDs'), 'fooIds');
 	t.is(camelCase('foo-bar'), 'fooBar');
 	t.is(camelCase('foo-bar-baz'), 'fooBarBaz');
 	t.is(camelCase('foo--bar'), 'fooBar');
@@ -20,8 +23,8 @@ test('camelCase', t => {
 	t.is(camelCase('__foo__bar__'), 'fooBar');
 	t.is(camelCase('foo bar'), 'fooBar');
 	t.is(camelCase('  foo  bar  '), 'fooBar');
-	t.is(camelCase('-'), '-');
-	t.is(camelCase(' - '), '-');
+	t.is(camelCase('-'), '');
+	t.is(camelCase(' - '), '');
 	t.is(camelCase('fooBar'), 'fooBar');
 	t.is(camelCase('fooBar-baz'), 'fooBarBaz');
 	t.is(camelCase('foìBar-baz'), 'foìBarBaz');
@@ -37,6 +40,13 @@ test('camelCase', t => {
 	t.is(camelCase(['', '']), '');
 	t.is(camelCase('--'), '');
 	t.is(camelCase(''), '');
+	t.is(camelCase('_'), '');
+	t.is(camelCase(' '), '');
+	t.is(camelCase('.'), '');
+	t.is(camelCase('..'), '');
+	t.is(camelCase('--'), '');
+	t.is(camelCase('  '), '');
+	t.is(camelCase('__'), '');
 	t.is(camelCase('--__--_--_'), '');
 	t.is(camelCase(['---_', '--', '', '-_- ']), '');
 	t.is(camelCase('foo bar?'), 'fooBar?');
@@ -86,8 +96,8 @@ test('camelCase with pascalCase option', t => {
 	t.is(camelCase('__foo__bar__', {pascalCase: true}), 'FooBar');
 	t.is(camelCase('foo bar', {pascalCase: true}), 'FooBar');
 	t.is(camelCase('  foo  bar  ', {pascalCase: true}), 'FooBar');
-	t.is(camelCase('-', {pascalCase: true}), '-');
-	t.is(camelCase(' - ', {pascalCase: true}), '-');
+	t.is(camelCase('-', {pascalCase: true}), '');
+	t.is(camelCase(' - ', {pascalCase: true}), '');
 	t.is(camelCase('fooBar', {pascalCase: true}), 'FooBar');
 	t.is(camelCase('fooBar-baz', {pascalCase: true}), 'FooBarBaz');
 	t.is(camelCase('foìBar-baz', {pascalCase: true}), 'FoìBarBaz');
@@ -160,6 +170,9 @@ test('camelCase with preserveConsecutiveUppercase option', t => {
 	t.is(camelCase('РозовыйПушистыйFOOдинорогиf', {preserveConsecutiveUppercase: true}), 'розовыйПушистыйFOOдинорогиf');
 	t.is(camelCase('桑德在这里。', {preserveConsecutiveUppercase: true}), '桑德在这里。');
 	t.is(camelCase('桑德_在这里。', {preserveConsecutiveUppercase: true}), '桑德在这里。');
+	/// https://github.com/sindresorhus/camelcase/issues/95
+	/// t.is(camelCase('IDs', {preserveConsecutiveUppercase: true}), 'ids');
+	t.is(camelCase('FooIDs', {preserveConsecutiveUppercase: true}), 'fooIDs');
 });
 
 test('camelCase with both pascalCase and preserveConsecutiveUppercase option', t => {
@@ -215,7 +228,9 @@ test('camelCase with disabled locale', t => {
 test('invalid input', t => {
 	t.throws(() => {
 		camelCase(1);
-	}, /Expected the input to be/);
+	}, {
+		message: /Expected the input to be/,
+	});
 });
 
 /* eslint-disable no-extend-native */
@@ -229,11 +244,11 @@ const withLocaleCaseFunctionsMocked = fn => {
 
 	Object.defineProperty(String.prototype, 'toLocaleUpperCase', {
 		...toLocaleUpperCase,
-		value: throwWhenBeingCalled
+		value: throwWhenBeingCalled,
 	});
 	Object.defineProperty(String.prototype, 'toLocaleLowerCase', {
 		...toLocaleLowerCase,
-		value: throwWhenBeingCalled
+		value: throwWhenBeingCalled,
 	});
 
 	try {
